function getError(action, option, xhr) {
  let msg;
  if (xhr.responseType === 'blob') {
    return;
  }
  if (xhr.response) {
    msg = `${xhr.response.error || xhr.response}`;
  } else if (xhr.responseText) {
    msg = `${xhr.responseText}`;
  } else {
    msg = `fail to post ${action} ${xhr.status}`;
  }

  const err = new Error(msg);
  err.status = xhr.status;
  err.method = 'post';
  err.url = action;
  return err;
}

function getBody(xhr) {
  let text;
  if (xhr.responseType === 'blob') {
    // let resHeader = xhr.getResponseHeader('content-disposition');
    // resHeader.match(/filename="(.+)"/)
    // return {
    //   fileName:RegExp.$1,
    //   blob:xhr.response
    // }
    return xhr.response;
  } else {
    text = xhr.responseText || xhr.response;
  }
  if (!text) {
    return text;
  }

  try {
    return JSON.parse(text);
  } catch (e) {
    return text;
  }
}

export default function upload(option) {
  return new Promise((resolve, reject) => {
    if (typeof XMLHttpRequest === 'undefined') {
      resolve();
      return;
    }
    const xhr = new XMLHttpRequest();
    const action = option.action;
    let formData;
    if (xhr.upload) {
      xhr.upload.onprogress = function progress(e) {
        if (e.total > 0) {
          e.percent = ~~((e.loaded / e.total) * 100);
        }
        option.onProgress(e);
      };
    }
    xhr.onerror = function error(e) {
      option.onError(e);
      reject(e);
    };

    xhr.onload = function onload() {
      if (xhr.status < 200 || xhr.status >= 300) {
        option.onError && option.onError(getError(action, option, xhr));
        reject(getError(action, option, xhr));
      } else {
        option.onSuccess && option.onSuccess(getBody(xhr));
        resolve(getBody(xhr));
      }
    };

    if (option.method == 'get') {
      xhr.onprogress = function progress(e) {
        if (e.total > 0) {
          e.percent = ~~((e.loaded / e.total) * 100);
        }
        option.onProgress(e);
      };
      xhr.open('get', action, true);
      xhr.responseType = 'blob';
    } else {
      formData = new FormData();

      if (option.data) {
        Object.keys(option.data).forEach(key => {
          formData.append(key, option.data[key]);
        });
      }

      formData.append(option.filename, option.file, option.file.name);
      xhr.open('post', action, true);
    }
    if (option.withCredentials && 'withCredentials' in xhr) {
      xhr.withCredentials = true;
    }

    const headers = option.headers || {};

    for (let item in headers) {
      if (headers.hasOwnProperty(item) && headers[item] !== null) {
        xhr.setRequestHeader(item, headers[item]);
      }
    }
    if (option.method == 'get') {
      xhr.send();
    } else {
      xhr.send(formData);
    }
  });
}
