import { getFileIcon } from './utils';
import ajax from './ajax';
export default {
  props: {
    name: [String],
    keyName: [String],
    fileSize: [String],
    fileSuffix: [String],
    previewUrl: [String],
    displayName: [String],  // 展示名字
    downloadUrl: String,
    headers: Object,
    preview: Function,  // 预览回调
  },
  data() {
    return {
      loading: false,
      status: '',
      percentage: 0
    };
  },
  computed: {
    fileTypeImg() {
      return getFileIcon(this.name.replace(/.+\./, ''));
    }
  },
  methods: {
    handleUploadProcess(e) {
      this.percentage = e.percent > 99 ? 99 : e.percent;
    },
    handleUploadError(e) {
      this.status = 'exception';
      setTimeout(() => {
        this.status = '';
        this.loading = false;
      }, 1000);
    },
    handleUploadSuccess(blob) {
      let fileReader = new FileReader();
      fileReader.onload = e => {
        this.percentage = 100;
        let downDom = document.createElement('a');
        downDom.href = e.target.result;
        downDom.download = this.name;
        downDom.click();
        downDom = null;
        this.resetLoading();
      };
      fileReader.readAsDataURL(blob);
    },
    resetLoading() {
      this.loading = false;
      this.status = '';
      this.percentage = 0;
    },
    downloadFile() {
      let option = {
        action: `${this.downloadUrl}?keyName=${this.keyName}&fileUrl=${this.keyName}&originalFilename=${this.name}`,
        method: 'get',
        onProgress: this.handleUploadProcess,
        onError: this.handleUploadError,
        onSuccess: this.handleUploadSuccess,
        headers: this.headers
      };
      this.loading = true;
      this.percentage = 1;
      ajax(option);
    },
    handlerFilePreview(url='') {
        if (!url) {
            return false;
        }
        if (this.preview && typeof this.preview === 'function') {
            return this.preview(url);
        }
        window.open(url);
    },
    handlerFileName(fileData) {
        if (!fileData) {
            return false;
        }
        if (this.clickFileName && typeof this.clickFileName === 'function') {
            return this.clickFileName(fileData);
        }
        this.downloadFile();
    }
  }
};
