const fileMiteTypes = {
    JPG: ["FFD8FFE0", "FFD8FFE1", "FFD8FFFE"],
    JPEG: ["FFD8FFE0", "FFD8FFE1", "FFD8FFFE"],
    JPE: ["FFD8FFE0", "FFD8FFE1", "FFD8FFFE"],
    PNG: ["89504E47", "FFD8FFE0"],
    GIF: "47494638",
    PDF: "255044",
    DOC: ["0D444F43", "D0CF11E0"],
    DOCX: "504B0304",
    PPTX: "504B0304",
    PPT: "D0CF11E0",
    XLSX: "504B0304",
    XLS: "D0CF11E0",
    TEXT: "D0CF11E0",
    TXT: "D0CF11E0",
    "7Z": "377ABCAF",
    ZIP: ["504B0304", "504B0506", "504B0708"],
};
let uid = 0;

// export function getUid() {
//   return uid++;
// }
export function getUid(len = 8, radix=20) {

      var chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
  
      var uuid = [], i;
  
      radix = radix || chars.length;
  
      if (len) {
        for (i = 0; i < len; i++) uuid[i] = chars[0 | Math.random()*radix];
      } else {
        var r;
        uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
        uuid[14] = '4';
  
        for (i = 0; i < 36; i++) {
  
          if (!uuid[i]) {
            r = 0 | Math.random()*16;
            uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
          }
        }
      }
      return uuid.join('');
  }

export function getFileIcon(type) {
  type = type.toUpperCase();
  switch (type) {
    case "JPG":
    case "JPEG":
    case "JPE":
    case "PNG":
    case "GIF":
      return "aimm-icon-image-file";
    case "PDF":
      return "aimm-icon-pdf-file";
    case "DOC":
    case "DOCX":
      return "aimm-icon-word-file";
    case "XLSX":
    case "XLS":
      return "aimm-icon-excel-file";
    case "ZIP":
      return "aimm-icon-zip-file";
    case "7Z":
      return "aimm-icon-zip-file";
    default:
      return "aimm-icon-other-file";
  }
}

export function fileTypeValidator(file, fileType) {
    
  let fileSlice = file.slice(0, 10);
  let fileReader = new FileReader();
  return new Promise((resolve, reject) => {
    fileReader.onload = (e) => {
      let arrayBuffer = e.target.result;
      let dateView = new DataView(arrayBuffer);
      let hexCode = dateView
        .getUint32(0, false)
        .toString(16)
        .toUpperCase();

      let type = fileType.toUpperCase();
      let mite = fileMiteTypes[type];
      if (mite) {
        if (Array.isArray(mite)) {
          resolve(mite.some((el) => hexCode.includes(el)));
        } else {
          resolve(hexCode.includes(mite));
        }
      } else {
        reject({
          message: "not allow file type!",
        });
      }
    };
    fileReader.onerror = (err) => {
      reject(err);
    };
    fileReader.readAsArrayBuffer(fileSlice);
  });
}

export const formatParams = (params) => {
  let str = "";
  for (let key in params) {
    str += `${key}=${params[key]}&`;
  }
  return str.slice(0, str.length - 1);
};

export const sleep = async (timer) => {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve();
    }, timer);
  });
};

// export const accept = [
//   "gif",
//   "jpg",
//   "jpeg",
//   "png",
//   "txt",
//   "pdf",
//   "doc",
//   "docx",
//   "xls",
//   "xlsx",
//   "ppt",
//   "pptx",
//   "7z",
//   "zip",
// ];

export const accept = [
    
    "application/pdf",//PDF
    "application/msword",//DOC
    "application/vnd.openxmlformats-officedocument.wordprocessingml.document",//DOCX
    "application/vnd.openxmlformats-officedocument.wordprocessingml.template",//dotx
    "application/vnd.ms-excel",//xls
    "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",//XLXS
    "text/plain", //txt
    "image/png",
    "image/jpeg",//JPG,JPEG
    "image/png",//JPG,JPEG
    "application/vnd.ms-powerpoint",//PPT
    "application/vnd.openxmlformats-officedocument.presentationml.presentation",//PPTX
    "application/x-7z-compressed",//7z,
    "application/x-rar-compressed",//rar,
    "application/zip",//ZIP
    "application/x-zip-compressed",
    "text/markdown",
]
