// 只能是字母、数字和下划线，长度不限制
export const normalPasswordReg = /^\w+$/;

//允许 小写字母 a-z、大写字母 A-Z、数字 0-9、下划线 _、 连接符 -，且默认长度在 6-18 位数
export const passwordLimit = (start = 8, end = 16) => {
  return `/^[a-zA-Z0-9_-]{${start},${end}}$/`;
};

// 必须包含数字+小写字母+大写字母的密码，且默认长度在8-10位之间
export const passwordForceLimit = (start = 10, end = 10) => {
  return `/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z]).{${start},${end}}$/`;
};

//允许有一个字符符合 [A-Za-z0-9_] 之后可以为 [A-Za-z0-9_-+.] + @ + 允许有一个字符符合 [A-Za-z0-9_] 之后可以为 [A-Za-z0-9_-.] + . + 允许有一个字符符合 [A-Za-z0-9_] 之后可以有 [A-Za-z0-9_-.] 的邮箱：
export const isEmail = /^\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/;

//18 位身份证号，尾数是数字或者字母 X：
export const ID18 = /^(\d{6})(\d{4})(\d{2})(\d{2})(\d{3})([0-9]|X)$/;

//15 或者 18 位身份证号，尾数可以是数字及 X 或者 x：
export const ID18Or15 = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;

//以 1 开头，第二位数是 3/4/5/6/7/8 的 11 位手机号码：
export const isChinaMobile = /^1[3,4,5,6,7,8,9]\d{9}$/;

export const AimmReg = {
  isChinaMobile: isChinaMobile,
  ID18Or15: ID18Or15,
  ID18: ID18,
  isEmail: isEmail,
  passwordForceLimit: passwordForceLimit,
  passwordLimit: passwordLimit,
  normalPasswordReg: normalPasswordReg,
};
